@@ -8,6 +8,7 @@ WoRMS: http://marinespecies.org/rest/
 import concurrent.futures
 import logging
 from functools import lru_cache
+from typing import List
 
 import numpy as np
 import pandas as pd
@@ -31,6 +32,7 @@ def request_obis(eco_code: int = None, aphia_id: int = None) -> pd.DataFrame:
     Returns
     -------
     pandas.DataFrame
+        Obis data
 
     Raises
     -------
@@ -218,8 +220,7 @@ def _fetch_worms(aphia_id: int) -> pd.DataFrame:
     ----
     Exceptions are logged to log file and they do not raise
     Exception because not all species are observed in WoRMS so the program can
-    continue
-    without exit.
+    continue without exit.
 
     Parameters
     ----------
@@ -229,6 +230,7 @@ def _fetch_worms(aphia_id: int) -> pd.DataFrame:
     Returns
     -------
     pandas DataFrame
+        Data on the specific species
     """
     try:
         r = requests.get(
@@ -267,7 +269,7 @@ def _fetch_worms(aphia_id: int) -> pd.DataFrame:
             return pd.DataFrame()
 
 
-def request_worms(aphia_ids: int) -> pd.DataFrame:
+def request_worms(aphia_ids: List[int]) -> pd.DataFrame:
     """
     Request call to WoRMS API web service
 
@@ -275,12 +277,13 @@ def request_worms(aphia_ids: int) -> pd.DataFrame:
 
     Parameters
     ----------
-    aphia_ids: int
-        aphia ID of species
+    aphia_ids: list of int
+        aphia IDs of species
 
     Returns
     -------
     pandas DataFrame
+        Worms data
     """
     results_dfs = []
 
