@@ -79,7 +79,8 @@ def marine_ecoregions(**kwargs) -> gpd.GeoDataFrame:
             meow_gpd = meow_gpd[meow_gpd[colname].isin(eco_codes)]
         else:
             meow_gpd = meow_gpd[meow_gpd[colname].notnull()]
-            meow_gpd = meow_gpd[meow_gpd[colname].str.contains(param[1], regex=True)]
+            meow_gpd = meow_gpd[meow_gpd[colname].str.contains(
+                param[1], regex=True)]
         meow_gpd = meow_gpd.reset_index(drop=True)
 
     return meow_gpd[
@@ -103,6 +104,7 @@ def get_obis(eco_code: int = None, aphia_id: int = None) -> pd.DataFrame:
     Returns
     -------
     pandas.DataFrame
+        Species information from the obis database
 
     Raises
     ------
@@ -122,7 +124,7 @@ def get_obis(eco_code: int = None, aphia_id: int = None) -> pd.DataFrame:
     elif aphia_id:
         df_obis = request_obis(aphia_id=aphia_id)
     else:
-        raise ValueError("Either geometry or aphiaID must be specified")
+        raise ValueError("Either eco_code or aphiaID must be specified")
 
     df_obis["ECO_CODE"] = eco_code
 
@@ -172,12 +174,13 @@ class Species:
                 "No record found in OBIS for species with "
                 "aphia ID: {}".format(aphia_id)
             )
-        self.observations: pd.DataFrame = observations(self.obis.iloc[0:1])
+        self.observations: pd.DataFrame = observations(self.obis.iloc[0:1],
+                                                       species=True)
 
     @property
     def reported_as_alien(self) -> pd.DataFrame:
         """
-        Returns marine eco regions where the species is alien.
+        Get marine eco regions where the species is alien.
 
         The eco-region information is based on OBIS lat/log linked to
         eco-regions and only these obeservations are reported.
@@ -187,7 +190,7 @@ class Species:
         Returns
         -------
         pd.DataFrame
-            table of aliens observations
+            Table of aliens observations
         """
         if self.observations.empty:
             return pd.DataFrame()
@@ -221,98 +224,25 @@ class Species:
                 "decimalLongitude_x": "decimalLongitude",
                 "geometry_x": "geometry",
                 "species_x": "species",
-            },
-            inplace=True,
-        )
-        df_intersection.drop_duplicates(["ECO_CODE"], inplace=True)
-
-        df_intersection = df_intersection[
-            [
-                "ECOREGION",
-                "MRGID",
-                "aphiaID",
-                "dataset",
-                "decimalLatitude",
-                "decimalLongitude",
-                "establishmentMeans",
-                "geometry",
-                "species",
-                "ECO_CODE",
-            ]
-        ]
-
-        return df_intersection
-
-    @property
-    def _reported_as_alien_and_native(self) -> pd.DataFrame:
-        """
-        Return all other marine eco regions where the species is reported as
-        both alien and native. The regions is in range of OBIS observation only
-        (means intersection of obis observation and all alien observations for
-         the species).
-
-        These are cases where a species is reported as alien and native. This can be
-        caused by large eco-regions where a species can be native in some places and
-        alien in others or by conflicting information in the different data sources. To
-        show all cases with native and alien status:
-
-        Note
-        ----
-
-        Hidden method for now, as this has an ambivalent meaning
-
-        Returns
-        -------
-        pd.DataFrame
-            species reported as both, aliens and natives in same eco-region
-        """
-        if self.observations.empty:
-            return pd.DataFrame()
-
-        not_aliens = self.observations[
-            self.observations["establishmentMeans"] != "Alien"
-        ].reset_index(drop=True)
-        not_aliens["ECO_CODE"] = not_aliens["ECO_CODE"].astype("int64")
-        df_intersection = pd.merge(
-            self.reported_as_alien, not_aliens, on="ECO_CODE", how="inner"
-        )
-
-        df_intersection.rename(
-            index=str,
-            columns={
-                "ECOREGION_x": "ECOREGION",
                 "MRGID_x": "MRGID",
-                "aphiaID_x": "aphiaID",
-                "decimalLatitude_x": "decimalLatitude",
-                "decimalLongitude_x": "decimalLongitude",
-                "geometry_x": "geometry",
-                "ECO_CODE_x": "ECO_CODE",
-                "species_x": "species",
+                "dataset_x": "dataset",
+                "establishmentMeans_x": "establishmentMeans",
             },
             inplace=True,
         )
-        df_intersection["dataset"] = df_intersection[["dataset_x", "dataset_y"]].apply(
-            lambda x: ",".join(x), axis=1
+        # Report as alien as soon as it is reported as alien in one of the
+        # datasources. Column dataset reports all datasources which report a
+        # species as alien.
+        df_intersection = df_intersection.groupby(
+            ["aphiaID", "ECO_CODE", "ECOREGION", "species", "MRGID"],
+            as_index=False)["dataset"].agg(
+            {"dataset": lambda x: ",".join(x)}
         )
-        df_intersection["establishmentMeans_y"].fillna("None", inplace=True)
-        df_intersection["establishmentMeans"] = df_intersection[
-            ["establishmentMeans_x", "establishmentMeans_y"]
-        ].apply(lambda x: ",".join(x), axis=1)
+        df_intersection = pd.merge(
+            df_intersection,
+            aliens[['geometry', 'ECO_CODE']],
+            on="ECO_CODE", how="left")
         df_intersection.drop_duplicates(["ECO_CODE"], inplace=True)
-        df_intersection = df_intersection[
-            [
-                "ECOREGION",
-                "MRGID",
-                "aphiaID",
-                "dataset",
-                "decimalLatitude",
-                "decimalLongitude",
-                "establishmentMeans",
-                "geometry",
-                "species",
-                "ECO_CODE",
-            ]
-        ]
 
         return df_intersection
 
@@ -329,12 +259,12 @@ class Species:
             table of observations
         """
 
-        df = self.obis.copy()
+        df = self.observations.copy()
 
         ecoregions = marine_ecoregions()
 
-        df["geometry"] = None
-        df["ECO_CODE"] = None
+        # df["geometry"] = None
+        # df["ECO_CODE"] = None
 
         def map_point_to_polygon(polygon, ecocode, ecoregion, lon, lat):
             """Check if a given point (lon, lat) within polygon"""
@@ -393,7 +323,8 @@ class Species:
         for item in self.all_occurrences.iterrows():
             try:
                 if type(item[1]["geometry"]) == sh_geo.MultiPolygon:
-                    polys.extend(list(sh_geo.MultiPolygon(item[1]["geometry"])))
+                    polys.extend(
+                        list(sh_geo.MultiPolygon(item[1]["geometry"])))
                 else:
                     polys.append(sh_geo.Polygon(item[1]["geometry"]))
             except Exception as e:
@@ -409,7 +340,8 @@ class Species:
             )
             plt.gca().add_patch(m_poly)
         ax1.set_title(
-            "Distribution of {} (from OBIS database)".format(self.obis.species.iloc[0])
+            "Distribution of {} (from OBIS database)".format(
+                self.obis.species.iloc[0])
         )
 
         ax2 = plt.subplot(3, 1, 2)
@@ -419,7 +351,8 @@ class Species:
         for item in self.reported_as_alien.iterrows():
             try:
                 if type(item[1]["geometry"]) == sh_geo.MultiPolygon:
-                    polys.extend(list(sh_geo.MultiPolygon(item[1]["geometry"])))
+                    polys.extend(
+                        list(sh_geo.MultiPolygon(item[1]["geometry"])))
                 else:
                     polys.append(sh_geo.Polygon(item[1]["geometry"]))
             except Exception as e:
@@ -434,7 +367,8 @@ class Species:
                 xym, facecolor="red", edgecolor="red", linewidth=1, alpha=0.7
             )
             plt.gca().add_patch(m_poly)
-        ax2.set_title("Alien distribution of {}".format(self.obis.species.iloc[0]))
+        ax2.set_title("Alien distribution of {}".format(
+            self.obis.species.iloc[0]))
 
         plt.show()
 
@@ -511,7 +445,11 @@ class MarineLife(object):
         list
             species names
         """
-        return self.obis["species"].unique().tolist()
+        df = self.observations[
+            self.observations["ECO_CODE"] == self.eco_code
+        ].reset_index(drop=True)
+
+        return df["species"].unique().tolist()
 
     @property
     def affected_by_invasive(self) -> List[str]:
@@ -568,7 +506,8 @@ def plot(eco_code):
             x = x.tolist()
             y = y.tolist()
             xym = list(zip(x, y))
-            poly = Polygon(xym, facecolor="blue", edgecolor="blue", linewidth=2)
+            poly = Polygon(xym, facecolor="blue",
+                           edgecolor="blue", linewidth=2)
             plt.gca().add_patch(poly)
     else:
         x, y = coords.exterior.coords.xy
