@@ -21,24 +21,37 @@ from marinvaders.readers import (
 )
 
 
-def observations(obis: pd.DataFrame) -> pd.DataFrame:
+def observations(obis: pd.DataFrame, species=False) -> pd.DataFrame:
     """
-    The main function, calls all data sources and merge them together.
+    Get the data from the online data sources.
+
+    Currently this obtains data from obis, worms and natcon.
+
+    Parameters
+    ----------
+    obis: pd.DataFrame
+        DataFrame of species from obis to be searched for
+    species: boolean
+        Flag used for NatCon source.
+        If False then it returns all NatCon data and the obis paramter is omitted.
+        If True the NatCon returns only subset specifed in obis parameter.
 
     Returns
     -------
     pd.DataFrame
+        DataFrame with all data but with droped duplicates.
+
     """
     logging.info("Processing observations.")
 
     worms_obs = worms(obis)
     gisd_obs = gisd(obis)
-    natcon_obs = natcon(obis)
+    natcon_obs = natcon(obis) if species else natcon()
 
     if all([worms_obs.empty, gisd_obs.empty, natcon_obs.empty]):
         return pd.DataFrame()
 
-    result = pd.concat([worms(obis), gisd(obis), natcon(obis)], sort=True).reset_index(
+    result = pd.concat([worms_obs, gisd_obs, natcon_obs], sort=True).reset_index(
         drop=True
     )
 
@@ -62,15 +75,13 @@ def worms(obis: pd.DataFrame) -> pd.DataFrame:
     Returns
     -------
     pandas.DataFrame
+        Worms data
     """
     logging.info("Processing WoRMS")
     df_worms = request_worms(obis["aphiaID"].unique())
     if df_worms.empty:
         return pd.DataFrame
 
-    # The establishmentMeans is invasive if equal to Alien otherwise native
-
-    # df_worms_invasive = df_worms[df_worms['establishmentMeans'] == 'Alien']
     df_worms["MRGID"] = df_worms["locationID"].apply(lambda x: int(x.split("/")[-1]))
 
     df_worms.drop(
@@ -165,6 +176,7 @@ def gisd(obis: pd.DataFrame) -> pd.DataFrame:
     Returns
     -------
     pandas.DataFrame
+        GISD data
     """
     logging.info("Processing GISD")
     try:
@@ -263,24 +275,28 @@ def gisd(obis: pd.DataFrame) -> pd.DataFrame:
     return result
 
 
-def natcon(obis: pd.DataFrame) -> pd.DataFrame:
+def natcon(obis: pd.DataFrame = None) -> pd.DataFrame:
     """
     Process observations for alien range from NatCon source.
 
     Returns
     -------
     pandas.DataFrame
+        Natcon data
     """
     logging.info("Processing NatCon")
     natcon = read_natcon()
     natcon["species"] = natcon["SPECIES_NAME"]
-    merged = obis.merge(natcon, on="species", how="inner")
-    merged = merged[["aphiaID", "species", "ECOREGION", "ECO_CODE_X"]]
-    merged["establishmentMeans"] = "Alien"
-    merged["dataset"] = "NatCon"
+    natcon = natcon[["aphiaID", "species", "ECOREGION", "ECO_CODE_X"]]
+    natcon["establishmentMeans"] = "Alien"
+    natcon["dataset"] = "NatCon"
+
+    if obis is not None:
+        natcon = natcon[natcon['aphiaID'].isin(obis['aphiaID'])]
+
     map_eco_mrgid = eco_mrgid_link()
     map_eco_mrgid = map_eco_mrgid[["MRGID", "ECO_CODE_X", "geometry"]]
 
-    result = merged.merge(map_eco_mrgid, on="ECO_CODE_X")
+    result = natcon.merge(map_eco_mrgid, on="ECO_CODE_X")
 
     return result
