@@ -20,7 +20,8 @@ def data_path() -> os.path:
 
     Returns
     -------
-    os path
+    os.path
+        Data path
     """
     this_dir, _ = os.path.split(__file__)
     return os.path.join(this_dir, "data")
@@ -50,6 +51,7 @@ def read_shapefile(shape_name: ShapeFiles) -> gpd.GeoDataFrame:
     Returns
     -------
     GeoPandas
+        Shapefile data
     """
     gdf = gpd.read_file(os.path.join(data_path(), shape_name.value))
 
@@ -70,6 +72,7 @@ def read_gisd_worms_link() -> pd.DataFrame:
     Returns
     -------
     pd.DataFrame
+        Distribution links
     """
     df = pd.read_excel(
         os.path.join(
@@ -92,13 +95,12 @@ def read_natcon() -> pd.DataFrame:
     Returns
     -------
     pd.DataFrame
+        Natcon data
     """
-    df = pd.read_excel(
-        os.path.join(data_path(), "natcon.xlsx"),
-        sheet_name="Species_distribution",
-        engine="openpyxl",
+    df = pd.read_csv(
+        os.path.join(data_path(), "NatConAddAphiaID_FV.csv"),
     )
-
+    df = df.dropna(subset=['aphiaID'])
     return df
 
 
@@ -110,6 +112,7 @@ def read_gisd() -> pd.DataFrame:
     Returns
     -------
     pd.DataFrame
+        GISD data
     """
     df = pd.read_json(os.path.join(data_path(), "gisd.json"))
 
@@ -125,6 +128,7 @@ def eco_mrgid_link() -> pd.DataFrame:
     Returns
     -------
     pd.DataFrame
+        eco-region code linked to MRGID
     """
     df = pd.read_hdf(os.path.join(data_path(), "eco_mrgid.h5"))
     df["MRGID"] = df["MRGID"].astype("int64")
@@ -140,6 +144,7 @@ def read_taxonomy() -> pd.DataFrame:
     Returns
     -------
     Pandas DataFrame
+        Affected species
     """
 
     # TODO: what is taxonomy doing? Ask Francesca? Independent of Eco-region
